Fix spelling throughout the codebase [codespell]
authorKim Alvefur <zash@zash.se>
Sun, 04 Feb 2018 01:51:25 +0100
changeset 8731 41c959c5c84b
parent 8730 285075a27f28
child 8732 c519c778f2b2
Fix spelling throughout the codebase [codespell]
doc/coding_style.txt
doc/names.txt
doc/net.server.lua
doc/session.txt
net/server_event.lua
net/server_select.lua
net/websocket/frames.lua
plugins/mod_admin_adhoc.lua
plugins/mod_iq.lua
plugins/mod_message.lua
plugins/mod_pep.lua
plugins/mod_pep_plus.lua
plugins/mod_presence.lua
plugins/mod_proxy65.lua
plugins/muc/muc.lib.lua
util/sasl/scram.lua
util/startup.lua
--- a/doc/coding_style.txt	Thu Apr 05 19:37:32 2018 +0200
+++ b/doc/coding_style.txt	Sun Feb 04 01:51:25 2018 +0100
@@ -7,7 +7,7 @@
 
 == Spacing ==
 
-No space between function names and parenthesis and parenthesis and paramters:
+No space between function names and parenthesis and parenthesis and parameters:
 
 		function foo(bar, baz)
 
--- a/doc/names.txt	Thu Apr 05 19:37:32 2018 +0200
+++ b/doc/names.txt	Sun Feb 04 01:51:25 2018 +0100
@@ -15,7 +15,7 @@
 	Eclaire	-	Idem (French)
 	Adel	-	Random
 	Younha	-	Read as "yuna"
-	Quezacotl	-	Mayan gods -> google for correct form and pronounciation
+	Quezacotl	-	Mayan gods -> google for correct form and pronunciation
 	Carbuncle	-	FF8 Guardian Force ^^
 	Protos	-	Mars satellite
 	mins	-	Derived from minstrel
--- a/doc/net.server.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/doc/net.server.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -135,7 +135,7 @@
 --[[ Links to two handles together, so anything written to one is piped to the other
 
 Arguments:
-  - sender, reciever: handles to link
+  - sender, receiver: handles to link
   - buffersize: maximum #bytes until sender will be locked
 ]]
 local function link(sender, receiver, buffersize)
--- a/doc/session.txt	Thu Apr 05 19:37:32 2018 +0200
+++ b/doc/session.txt	Sun Feb 04 01:51:25 2018 +0100
@@ -15,7 +15,7 @@
 	full_jid -- convenience for the above 3 as string in username@host/resource form (not defined before resource binding)
 	priority -- the resource priority, default: 0
 	presence -- the last non-directed presence with no type attribute. initially nil. reset to nil on unavailable presence.
-	interested -- true if the resource requested the roster. Interested resources recieve roster updates. Initially nil.
+	interested -- true if the resource requested the roster. Interested resources receive roster updates. Initially nil.
 	roster -- the user's roster. Loaded as soon as the resource is bound (session becomes a connected resource).
 	
 	-- methods --
--- a/net/server_select.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/net/server_select.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -132,7 +132,7 @@
 
 _readlistlen = 0 -- length of readlist
 _sendlistlen = 0 -- length of sendlist
-_timerlistlen = 0 -- lenght of timerlist
+_timerlistlen = 0 -- length of timerlist
 
 _sendtraffic = 0 -- some stats
 _readtraffic = 0
@@ -420,7 +420,7 @@
 		bufferlen = bufferlen + #data
 		if bufferlen > maxsendlen then
 			_closelist[ handler ] = "send buffer exceeded"	 -- cannot close the client at the moment, have to wait to the end of the cycle
-			handler.write = idfalse -- dont write anymore
+			handler.write = idfalse -- don't write anymore
 			return false
 		elseif socket and not _sendlist[ socket ] then
 			_sendlistlen = addsocket(_sendlist, socket, _sendlistlen)
@@ -531,7 +531,7 @@
 		else
 			succ, err, count = false, "unexpected close", 0;
 		end
-		if succ then	-- sending succesful
+		if succ then	-- sending successful
 			bufferqueuelen = 0
 			bufferlen = 0
 			_sendlistlen = removesocket( _sendlist, socket, _sendlistlen ) -- delete socket from writelist
--- a/net/websocket/frames.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/net/websocket/frames.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -112,9 +112,9 @@
 -- TODO: optimize
 local function apply_mask(str, key, from, to)
 	from = from or 1
-	if from < 0 then from = #str + from + 1 end -- negative indicies
+	if from < 0 then from = #str + from + 1 end -- negative indices
 	to = to or #str
-	if to < 0 then to = #str + to + 1 end -- negative indicies
+	if to < 0 then to = #str + to + 1 end -- negative indices
 	local key_len = #key
 	local counter = 0;
 	local data = {};
--- a/plugins/mod_admin_adhoc.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_admin_adhoc.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -369,7 +369,7 @@
 
 	{ name = "FORM_TYPE", type = "hidden", value = "http://prosody.im/protocol/s2s#list" };
 	{ name = "sessions", type = "text-multi", label = "Connections:" };
-	{ name = "num_in", type = "text-single", label = "#incomming connections:" };
+	{ name = "num_in", type = "text-single", label = "#incoming connections:" };
 	{ name = "num_out", type = "text-single", label = "#outgoing connections:" };
 };
 
--- a/plugins/mod_iq.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_iq.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -13,7 +13,7 @@
 
 if module:get_host_type() == "local" then
 	module:hook("iq/full", function(data)
-		-- IQ to full JID recieved
+		-- IQ to full JID received
 		local origin, stanza = data.origin, data.stanza;
 
 		local session = full_sessions[stanza.attr.to];
@@ -27,7 +27,7 @@
 end
 
 module:hook("iq/bare", function(data)
-	-- IQ to bare JID recieved
+	-- IQ to bare JID received
 	local stanza = data.stanza;
 	local type = stanza.attr.type;
 
@@ -44,7 +44,7 @@
 end);
 
 module:hook("iq/self", function(data)
-	-- IQ to self JID recieved
+	-- IQ to self JID received
 	local stanza = data.stanza;
 	local type = stanza.attr.type;
 
@@ -60,7 +60,7 @@
 end);
 
 module:hook("iq/host", function(data)
-	-- IQ to a local host recieved
+	-- IQ to a local host received
 	local stanza = data.stanza;
 	local type = stanza.attr.type;
 
--- a/plugins/mod_message.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_message.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -63,7 +63,7 @@
 end
 
 module:hook("message/full", function(data)
-	-- message to full JID recieved
+	-- message to full JID received
 	local origin, stanza = data.origin, data.stanza;
 
 	local session = full_sessions[stanza.attr.to];
@@ -75,7 +75,7 @@
 end, -1);
 
 module:hook("message/bare", function(data)
-	-- message to bare JID recieved
+	-- message to bare JID received
 	local origin, stanza = data.origin, data.stanza;
 
 	return process_to_bare(stanza.attr.to or (origin.username..'@'..origin.host), origin, stanza);
--- a/plugins/mod_pep.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_pep.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -117,7 +117,7 @@
 end
 
 module:hook("presence/bare", function(event)
-	-- inbound presence to bare JID recieved
+	-- inbound presence to bare JID received
 	local origin, stanza = event.origin, event.stanza;
 	local user = stanza.attr.to or (origin.username..'@'..origin.host);
 	local t = stanza.attr.type;
--- a/plugins/mod_pep_plus.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_pep_plus.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -303,7 +303,7 @@
 end
 
 module:hook("presence/bare", function(event)
-	-- inbound presence to bare JID recieved
+	-- inbound presence to bare JID received
 	local origin, stanza = event.origin, event.stanza;
 	local t = stanza.attr.type;
 	local is_self = not stanza.attr.to;
--- a/plugins/mod_presence.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_presence.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -253,7 +253,7 @@
 end
 
 local outbound_presence_handler = function(data)
-	-- outbound presence recieved
+	-- outbound presence received
 	local origin, stanza = data.origin, data.stanza;
 
 	local to = stanza.attr.to;
@@ -281,7 +281,7 @@
 module:hook("pre-presence/host", outbound_presence_handler);
 
 module:hook("presence/bare", function(data)
-	-- inbound presence to bare JID recieved
+	-- inbound presence to bare JID received
 	local origin, stanza = data.origin, data.stanza;
 
 	local to = stanza.attr.to;
@@ -307,7 +307,7 @@
 	return true;
 end);
 module:hook("presence/full", function(data)
-	-- inbound presence to full JID recieved
+	-- inbound presence to full JID received
 	local origin, stanza = data.origin, data.stanza;
 
 	local t = stanza.attr.type;
--- a/plugins/mod_proxy65.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/mod_proxy65.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -44,7 +44,7 @@
 		end -- else error, unexpected input
 		conn:write("\5\255"); -- send (SOCKS version 5, no acceptable method)
 		conn:close();
-		module:log("debug", "Invalid SOCKS5 greeting recieved: '%s'", b64(data));
+		module:log("debug", "Invalid SOCKS5 greeting received: '%s'", b64(data));
 	else -- connection request
 		--local head = string.char( 0x05, 0x01, 0x00, 0x03, 40 ); -- ( VER=5=SOCKS5, CMD=1=CONNECT, RSV=0=RESERVED, ATYP=3=DOMAIMNAME, SHA-1 size )
 		if #data == 47 and data:sub(1,5) == "\5\1\0\3\40" and data:sub(-2) == "\0\0" then
@@ -66,7 +66,7 @@
 		else -- error, unexpected input
 			conn:write("\5\1\0\3\0\0\0"); -- VER, REP, RSV, ATYP, BND.ADDR (sha), BND.PORT (2 Byte)
 			conn:close();
-			module:log("debug", "Invalid SOCKS5 negotiation recieved: '%s'", b64(data));
+			module:log("debug", "Invalid SOCKS5 negotiation received: '%s'", b64(data));
 		end
 	end
 end
--- a/plugins/muc/muc.lib.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/plugins/muc/muc.lib.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -576,7 +576,7 @@
 				self:route_stanza(pr);
 			end
 			if is_first_dest_session and is_last_orig_session then -- Normal nick change
-				log("debug", "no sessions in %s left; publically marking as nick change", orig_occupant.nick);
+				log("debug", "no sessions in %s left; publicly marking as nick change", orig_occupant.nick);
 				orig_x:tag("status", {code = "303";}):up();
 			else -- The session itself always needs to see a nick change
 				-- don't want to get our old nick's available presence,
--- a/util/sasl/scram.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/util/sasl/scram.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -160,7 +160,7 @@
 			end
 			self.username = username;
 
-			-- retreive credentials
+			-- retrieve credentials
 			local stored_key, server_key, salt, iteration_count;
 			if self.profile.plain then
 				local password, status = self.profile.plain(self, username, self.realm)
--- a/util/startup.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/util/startup.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -43,7 +43,7 @@
 		print("\n");
 		print("**************************");
 		if level == "parser" then
-			print("A problem occured while reading the config file "..filename);
+			print("A problem occurred while reading the config file "..filename);
 			print("");
 			local err_line, err_message = tostring(err):match("%[string .-%]:(%d*): (.*)");
 			if err:match("chunk has too many syntax levels$") then
--- a/net/server_event.lua	Thu Apr 05 19:37:32 2018 +0200
+++ b/net/server_event.lua	Sun Feb 04 01:51:25 2018 +0100
@@ -5,9 +5,9 @@
 
 			notes:
 			-- when using luaevent, never register 2 or more EV_READ at one socket, same for EV_WRITE
-			-- you cant even register a new EV_READ/EV_WRITE callback inside another one
+			-- you can't even register a new EV_READ/EV_WRITE callback inside another one
 			-- to do some of the above, use timeout events or something what will called from outside
 			-- dont let garbagecollect eventcallbacks, as long they are running
 			-- when using luasec, there are 4 cases of timeout errors: wantread or wantwrite during reading or writing
 
 --]]
@@ -157,7 +157,7 @@
 		self.fatalerror = err
 		self.conn = nil  -- cannot be used anymore
 		if call_onconnect then
-			self.ondisconnect = nil  -- dont call this when client isnt really connected
+			self.ondisconnect = nil  -- don't call this when client isn't really connected
 		end
 		self:_close()
 		debug( "fatal error while ssl wrapping:", err )
@@ -200,7 +200,7 @@
 			end
 			if self.fatalerror then
 				if call_onconnect then
-					self.ondisconnect = nil  -- dont call this when client isnt really connected
+					self.ondisconnect = nil  -- don't call this when client isn't really connected
 				end
 				self:_close()
 				debug( "handshake failed because:", self.fatalerror )
@@ -229,7 +229,7 @@
 		_ = self.eventsession and self.eventsession:close( )
 		_ = self.eventwritetimeout and self.eventwritetimeout:close( )
 		_ = self.eventreadtimeout and self.eventreadtimeout:close( )
-		-- call ondisconnect listener (wont be the case if handshake failed on connect)
+		-- call ondisconnect listener (won't be the case if handshake failed on connect)
 		_ = self.ondisconnect and self:ondisconnect( self.fatalerror ~= "client to close" and self.fatalerror)
 		_ = self.conn and self.conn:close( ) -- close connection
 		_ = self._server and self._server:counter(-1);
@@ -517,7 +517,7 @@
 			interface.writebuffer = { t_concat(interface.writebuffer) }
 			local succ, err, byte = interface.conn:send( interface.writebuffer[1], 1, interface.writebufferlen )
 			--vdebug( "write data:", interface.writebuffer, "error:", err, "part:", byte )
-			if succ then  -- writing succesful
+			if succ then  -- writing successful
 				interface.writebuffer[1] = nil
 				interface.writebufferlen = 0
 				interface:ondrain();
@@ -546,7 +546,7 @@
 						return -1;
 					end
 					interface.eventwritetimeout = addevent( base, nil, EV_TIMEOUT, callback, cfg.WRITE_TIMEOUT )  -- reg a new timeout event
-					debug( "wantread during write attempt, reg it in readcallback but dont know what really happens next..." )
+					debug( "wantread during write attempt, reg it in readcallback but don't know what really happens next..." )
 					-- hopefully this works with luasec; its simply not possible to use 2 different write events on a socket in luaevent
 					return -1
 				end
@@ -602,8 +602,8 @@
 				end
 				interface.eventreadtimeout = addevent( base, nil, EV_TIMEOUT,
 					function( ) interface:_close() end, cfg.READ_TIMEOUT)
-				debug( "wantwrite during read attempt, reg it in writecallback but dont know what really happens next..." )
-				-- to be honest i dont know what happens next, if it is allowed to first read, the write etc...
+				debug( "wantwrite during read attempt, reg it in writecallback but don't know what really happens next..." )
+				-- to be honest i don't know what happens next, if it is allowed to first read, the write etc...
 			else  -- connection was closed or fatal error
 				interface.fatalerror = err
 				debug( "connection failed in read event:", interface.fatalerror )
@@ -5,9 +5,9 @@
 			-- to do some of the above, use timeout events or something what will called from outside
-			-- dont let garbagecollect eventcallbacks, as long they are running
+			-- don't let garbagecollect eventcallbacks, as long they are running
 			-- when using luasec, there are 4 cases of timeout errors: wantread or wantwrite during reading or writing
 